@@ -28,11 +28,12 @@ import java.util.Random;
 import dmLab.array.FArray;
 import dmLab.array.functions.SelectFunctions;
 import dmLab.classifier.Classifier;
+import dmLab.classifier.PredictionResult;
 import dmLab.mcfs.MCFSParams;
 import dmLab.mcfs.attributesID.AttributesID;
 import dmLab.mcfs.attributesRI.AttributesRI;
-import dmLab.utils.cmatrix.AccuracyMeasure;
 import dmLab.utils.cmatrix.ConfusionMatrix;
+import dmLab.utils.cmatrix.QualityMeasure;
 import dmLab.utils.statList.StatsList;
 import dmLab.utils.statList.StatsObject;
 
@@ -40,7 +41,6 @@ public class Projection
 {    
     private MCFSParams mcfsParams;
     private Split split;
-    private ConfusionMatrix confusionMatrix;
     private StatsList splitsStats;
     private SelectFunctions selectFunctions;
     
@@ -49,19 +49,24 @@ public class Projection
     {
         this.mcfsParams=mcfsParams;
         split=new Split(mcfsParams, random);
-        confusionMatrix=null;
         selectFunctions = new SelectFunctions(random);
     }
     //*************************************
     public ConfusionMatrix projectionLoop(Classifier classifier, FArray inputArray,
             AttributesRI attrRI[], AttributesID attrIDependencies)
-    {
+    {    	
         splitsStats = new StatsList();
-        splitsStats.addHeader("acc,wAcc,errors",',');
+     
+        ConfusionMatrix confusionMatrix;
+        if(inputArray.isTargetNominal()){
+        	confusionMatrix = new ConfusionMatrix(inputArray.getColNames(true)[inputArray.getDecAttrIdx()],inputArray.getDecValuesStr());
+            splitsStats.addHeader("acc,wAcc,errors",',');
+        }
+        else{
+            confusionMatrix = null;
+            splitsStats.addHeader("pearson,MAE,RMSE,SMAPE",',');
+        }
         
-        confusionMatrix=new ConfusionMatrix(inputArray.getColNames(true)[inputArray.getDecAttrIdx()],
-        		inputArray.getDecValuesStr());
-
         FArray projectionArray=null;
         int projectionSize=mcfsParams.projectionSizeAttr;
         
@@ -99,16 +104,26 @@ public class Projection
             	if (mcfsParams.verbose) 
             		System.out.println("limitedSizeArray# "+limitedSizeArray.info());
             }
-
-            //single confusion matrix
-            ConfusionMatrix matrix=split.splitLoop(classifier, limitedSizeArray, attrRI, attrIDependencies);            
-            confusionMatrix.add(matrix);
             
-            float[] stats = {(float)AccuracyMeasure.calcAcc(matrix.getMatrix()),
-            		(float)AccuracyMeasure.calcWAcc(matrix.getMatrix()),
-            		AccuracyMeasure.errors(matrix.getMatrix())};            
-            splitsStats.add(new StatsObject(stats));           
+            //single prediction and confusion matrix
+            PredictionResult predRes = split.splitLoop(classifier, limitedSizeArray, attrRI, attrIDependencies);
+            if(inputArray.isTargetNominal()){            
+	            ConfusionMatrix matrix = predRes.getConfusionMatrix();            
+	            confusionMatrix.add(matrix);	            
+	            float[] stats = {(float)QualityMeasure.calcAcc(matrix.getMatrix()),
+	            		(float)QualityMeasure.calcWAcc(matrix.getMatrix()),
+	            		QualityMeasure.errors(matrix.getMatrix())};
+	            splitsStats.add(new StatsObject(stats));
+            }else{
+	            float[] stats = {(float)predRes.getPredQuality(QualityMeasure.PEARSON),
+	            		(float)predRes.getPredQuality(QualityMeasure.MAE),
+	            		(float)predRes.getPredQuality(QualityMeasure.RMSE),
+	            		(float)predRes.getPredQuality(QualityMeasure.SMAPE)};
+	            splitsStats.add(new StatsObject(stats));            	
+            }            
+            
         }//end for
+                
         return confusionMatrix;
     }
     //*************************************
